# Load libraries
library(quantmod)
library(WDI)
library(tidyverse)
library(dynlm)

# Load economic data (Inflation and Unemployment from World Bank)

colnames(data) = c("year","x","y")
data=drop_na(data)

# Define time series variables
data =  data %>% mutate(y_lag1 = lag(y, 1), y_lag2 = lag(y, 2), y_lag3 = lag(y, 3),
                        x_lag1 = lag(x, 1), x_lag2 = lag(x, 2), x_lag3 = lag(x, 3)) 

data

# Define models
models = list(
  "Model_1" = y ~ y_lag1,
  "Model_2" = y ~ y_lag1 + y_lag2,
  "Model_3" = y ~ y_lag1 + y_lag2 + y_lag3,
  "Model_4" = y ~ y_lag1 + y_lag2 + x_lag1,
  "Model_5" = y ~ y_lag1 + y_lag2 + x_lag1 + x_lag2,
  "Model_6" = y ~ x + x_lag1 + x_lag2 + x_lag3
)

# Run regressions and summarize results
results = lapply(models, function(formula) {
  model = lm(formula, data = data)
  summary(model)
})

# Print model summaries
for (name in names(results)) {
  cat("\nModel:", name, "\n")
  print(results[[name]])
}
